"use client";

import { getFetch } from "@/lib/doFetch";
import { useRequest } from "ahooks";
import { Button } from "@nextui-org/react";
import { ArrowLeftOutlined } from "@ant-design/icons";
import EditCollection from "@/components/EditCollection";
import DeleteCollection from "@/components/DeleteCollection";
import { useRouter } from "next/navigation";
import {message} from 'antd';
import { IoMdShareAlt } from "react-icons/io";


const columns = [
  { name: "code", label: "编码" },
  { name: "faultType", label: "故障类型" },
  { name: "fault", label: "故障" },
  { name: "faultJudge", label: "判断条件" },
  { name: "faultReason", label: "故障原因" },
  { name: "faultFn", label: "解决方案" },
  { name: "faultMessage", label: "故障描述" },
];

export default function Detail({ params }) {
  //params.slug 路由传参获取
  const router = useRouter();

  const { data, refreshAsync } = useRequest(
    async () => {
      let res = await getFetch({
        url: "/api/collection/" + params.slug,
        params: {},
      });
      return res?.data;
    },
    {
      refreshDeps: [params.slug],
    }
  );

  const handleCopy = () => {
    const textToCopy = window.location.href;
    
    navigator.clipboard.writeText(textToCopy)
      .then(() => {
        message.success('链接复制成功')
      })
      .catch(err => {
        console.error('Failed to copy text to clipboard:', err);
      });
  };

  return (
    <div className="flex w-full flex-col">
      <div className="flex gap-4">
        <Button
          isIconOnly
          color="primary"
          variant="faded"
          aria-label="Take a add"
          onPress={() => {
            router.back();
          }}
        >
          <ArrowLeftOutlined></ArrowLeftOutlined>
        </Button>
        <Button color="primary" variant="flat" onPress={handleCopy} endContent={<IoMdShareAlt style={{fontSize:24}}/>}> 
         分享
        </Button>
        <EditCollection data={data} refresh={refreshAsync} />
        <DeleteCollection data={data} refresh={refreshAsync} />
      </div>
      <div className="w-full object-cover h-[180px] flex justify-center items-center bg-gradient-to-r from-cyan-500 to-blue-500 text-white text-xl rounded-2xl mt-6">
      {data?.name} 
      </div>    
      <ul className="divide-y divide-gray-200">
        {columns?.map((it) => {
          return (
            <li className="flex items-center py-4" key={it?.name}>
              <div className="ml-4">
                <div className="text-sm font-medium text-gray-900">{it?.label}</div>
                <div className="text-sm text-gray-500 mt-2">{data?.[it?.name]}</div>
              </div>
            </li>
          );
        })}
      </ul>
    </div>
  );
}
