import React from "react";
import {
  Modal,
  ModalContent,
  ModalHeader,
  ModalBody,
  ModalFooter,
  Button,
  useDisclosure,
} from "@nextui-org/react";
import { delFetch } from "@/lib/doFetch";
import { BsTrash3Fill } from "react-icons/bs";
import { useRouter } from "next/navigation";

export default function DeleteCollection({ refresh, data }) {
  const { isOpen, onOpen, onOpenChange } = useDisclosure();
  const router = useRouter();

  const handleButtonClick = async (close) => {
    await delFetch({ url: "/api/collection/" + data.id });
    router.back(); // 返回上一页
  };

  return (
    <>
      <Button isIconOnly color="danger" aria-label="Like" onPress={onOpen}>
        <BsTrash3Fill style={{ fontSize: "18px" }} />
      </Button>
      <Modal
        isOpen={isOpen}
        backdrop={"blur"}
        onOpenChange={onOpenChange}
        motionProps={{
          variants: {
            enter: {
              y: 0,
              opacity: 1,
              transition: {
                duration: 0.3,
                ease: "easeOut",
              },
            },
            exit: {
              y: -20,
              opacity: 0,
              transition: {
                duration: 0.2,
                ease: "easeIn",
              },
            },
          },
        }}
      >
        <ModalContent>
          {(onClose) => (
            <>
              <ModalHeader className="flex flex-col gap-1">
                是否删除该知识库
              </ModalHeader>
              <ModalBody>
                <p>删除后无法恢复请谨慎操作</p>
              </ModalBody>
              <ModalFooter>
                <Button color="danger" variant="light" onPress={onClose}>
                  取消
                </Button>
                <Button
                  color="danger"
                  onPress={() => {
                    handleButtonClick(onClose);
                  }}
                >
                  删除
                </Button>
              </ModalFooter>
            </>
          )}
        </ModalContent>
      </Modal>
    </>
  );
}
