import React, { useEffect } from "react";
import {
  Modal,
  ModalContent,
  ModalHeader,
  ModalBody,
  ModalFooter,
  Button,
  useDisclosure,
  Input,
  Avatar,
  Textarea,
} from "@nextui-org/react";
import { BsPencilSquare } from "react-icons/bs";
import { useForm, Controller } from "react-hook-form";
import { doFetch, putFetch } from "@/lib/doFetch";
import UploadImage from "./UploadImage";

const columns = [
  { name: "name", label: "知识库" },
  { name: "code", label: "编码" },
  { name: "faultType", label: "故障类型" },
  { name: "fault", label: "故障" },
  { name: "faultJudge", label: "判断条件" },
  { name: "faultReason", label: "故障原因" },
  { name: "faultFn", label: "解决方案" },
  { name: "faultMessage", label: "故障描述" },
];

export default function EditCollection({ refresh, data }) {
  const { isOpen, onOpen, onOpenChange } = useDisclosure();
  console.log(data);
  const { register, handleSubmit, control, setValue } = useForm({
    defaultValues: {
      ...data,
    },
  });

  useEffect(() => {
    if (data && isOpen === true) {
      columns?.map((it) => {
        setValue(it?.name, data[it?.name]);
      });
    }
  }, [data, isOpen]);

  const handleButtonClick = async (close) => {
    // 手动触发表单提交
    handleSubmit(onSubmit)();
    await refresh();
    close();
  };

  const onSubmit = async (params) => {
    await putFetch({ url: "/api/collection/" + data?.id, params });
    await refresh();
  };

  return (
    <>
      <Button
        isIconOnly
        color="warning"
        variant="faded"
        aria-label="Take a photo"
        onPress={onOpen}
      >
        <BsPencilSquare style={{ fontSize: "18px" }} />
      </Button>
      <Modal
        isOpen={isOpen}
        backdrop={"blur"}
        onOpenChange={onOpenChange}
        motionProps={{
          variants: {
            enter: {
              y: 0,
              opacity: 1,
              transition: {
                duration: 0.3,
                ease: "easeOut",
              },
            },
            exit: {
              y: -20,
              opacity: 0,
              transition: {
                duration: 0.2,
                ease: "easeIn",
              },
            },
          },
        }}
      >
        <ModalContent>
          {(onClose) => (
            <>
              <ModalHeader className="flex flex-col gap-1">
                编辑知识库
              </ModalHeader>
              <ModalBody>
                <form action="" className="flex flex-col gap-4">
                  <Controller
                    control={control}
                    rules={{
                      required: true,
                      maxLength: 20,
                    }}
                    render={({ field: { onChange, onBlur, value } }) => (
                      <Input
                        isRequired
                        isClearable
                        type="text"
                        label="知识库名称"
                        name="name"
                        onBlur={onBlur}
                        onValueChange={onChange}
                        value={value}
                      />
                    )}
                    name="name"
                  />
                  <Controller
                    control={control}
                    rules={{
                      required: true,
                      maxLength: 20,
                    }}
                    render={({ field: { onChange, onBlur, value } }) => (
                      <Input
                        isRequired
                        isClearable
                        type="text"
                        label="编码"
                        name="code"
                        onBlur={onBlur}
                        onValueChange={onChange}
                        value={value}
                      />
                    )}
                    name="code"
                  />

                  <Controller
                    control={control}
                    rules={{
                      required: true,
                      maxLength: 20,
                    }}
                    render={({ field: { onChange, onBlur, value } }) => (
                      <Input
                        isClearable
                        type="text"
                        label="故障类型"
                        name="faultType"
                        onBlur={onBlur}
                        onValueChange={onChange}
                        value={value}
                      />
                    )}
                    name="faultType"
                  />
                  <Controller
                    control={control}
                    rules={{
                      required: true,
                      maxLength: 20,
                    }}
                    render={({ field: { onChange, onBlur, value } }) => (
                      <Input
                        isClearable
                        type="text"
                        label="故障"
                        name="fault"
                        onBlur={onBlur}
                        onValueChange={onChange}
                        value={value}
                      />
                    )}
                    name="fault"
                  />

                  <Controller
                    control={control}
                    rules={{
                      required: true,
                      maxLength: 20,
                    }}
                    render={({ field: { onChange, onBlur, value } }) => (
                      <Textarea
                        isClearable
                        type="text"
                        label="判断条件"
                        name="faultJudge"
                        onBlur={onBlur}
                        onValueChange={onChange}
                        value={value}
                      />
                    )}
                    name="faultJudge"
                  />
                  <Controller
                    control={control}
                    rules={{
                      required: true,
                      maxLength: 20,
                    }}
                    render={({ field: { onChange, onBlur, value } }) => (
                      <Textarea
                        isClearable
                        type="text"
                        label="故障原因"
                        name="faultReason"
                        onBlur={onBlur}
                        onValueChange={onChange}
                        value={value}
                      />
                    )}
                    name="faultReason"
                  />

                  <Controller
                    control={control}
                    rules={{
                      required: true,
                      maxLength: 20,
                    }}
                    render={({ field: { onChange, onBlur, value } }) => (
                      <Textarea
                        isClearable
                        type="text"
                        label="解决方案"
                        name="faultFn"
                        onBlur={onBlur}
                        onValueChange={onChange}
                        value={value}
                      />
                    )}
                    name="faultFn"
                  />
                  <Controller
                    control={control}
                    rules={{
                      required: true,
                      maxLength: 20,
                    }}
                    render={({ field: { onChange, onBlur, value } }) => (
                      <Textarea
                        isClearable
                        type="text"
                        label="故障描述"
                        name="faultMessage"
                        onBlur={onBlur}
                        onValueChange={onChange}
                        value={value}
                      />
                    )}
                    name="faultMessage"
                  />
                </form>
              </ModalBody>
              <ModalFooter>
                <Button color="danger" variant="light" onPress={onClose}>
                  取消
                </Button>
                <Button
                  color="primary"
                  onPress={() => {
                    handleButtonClick(onClose);
                  }}
                >
                  提交
                </Button>
              </ModalFooter>
            </>
          )}
        </ModalContent>
      </Modal>
    </>
  );
}
